PipeSelections

Struct PipeSelections 

pub struct PipeSelections;
Pipes the selections of a Buffer through an external command

This can be useful if you, for example, don’t have access to a formatter, but want to format text, so you pass it to PipeSelections with fold as the command, or things of the sort.

Implementations