pub struct DuatBase {
pub default_opts_parser: bool,
}Expand description
The plugin for duat-base
This plugin will setup forms, hooks, completions, and add a
default parser for BufferOpts.
The provided Ns will be used for the DefaultOptsParser.
Fields
default_opts_parser: boolWether to enable the default opts parser.