Info

Struct Info 

pub struct Info { /* private fields */ }
A simple static widget, meant to just convey information

This is the most flexible of widgets, you can use it anywhere, just by pushing it around, or spawning it however you want, by making use of the PushSpecs, DynSpawnSpecs o StaticSpawnSpecs.

Implementations

Source

impl Info

pub fn new(text: Text) -> Self

Returns a new Info widget

This is the only Widget in duat-base that can be acquired this way, since it’s supposed to be versatile in where you position it. Every other widget has to be placed in specific locations, so they don’t offer a new method, which could be used in order to place them willy nilly.

pub fn set_text( pa: &mut Pass, info: &Handle<Self>, func: impl FnOnce(&mut Text), )

Mutate the Text of this Info.

This will also resize the widget to fit as much of it as possible.