pub struct LogBook {
pub close_on_unfocus: bool,
pub show_source: bool,
/* private fields */
}Fields
close_on_unfocus: boolWether to close this Widget after unfocusing, true by
default
show_source: boolWether the source of a log should be shown
Can be disabled for less noise. This option is ignored when there is custom formatting.
Implementations