pub struct LogBookOpts {
pub close_on_unfocus: bool,
pub hidden: bool,
pub side: Side,
pub height: f32,
pub width: f32,
pub show_source: bool,
}Expand description
Configuration for the LogBook
Fields
close_on_unfocus: boolWether to close the LogBook when unfocusing
Wether to hide the LogBook by default
side: SideTo which side to push the LogBook to
height: f32Requested height for the LogBook, ignored if pushing
horizontally
width: f32Requested width for the LogBook, ignored if pushing
vertically
show_source: boolWether the source of a log should be shown
Can be disabled for less noise. This option is ignored when there is custom formatting.
Implementations
Sourceimpl LogBookOpts
impl LogBookOpts
Sourcepub fn push_on(
self,
pa: &mut Pass,
push_target: &impl PushTarget,
) -> Handle<LogBook>
pub fn push_on( self, pa: &mut Pass, push_target: &impl PushTarget, ) -> Handle<LogBook>
Push a LogBook around the given PushTarget