pub struct Gutter { /* private fields */ }Expand description
A struct to hold diagnostic hints about a Buffer.
It sits on the sides of the Buffer, and tells you when there are
things to note about specific lines. These may be hints, warnings,
errors, or custom annotations.
Implementations