pub struct Info { /* private fields */ }Expand description
A simple static widget, meant to just convey information
This is the most flexible of widgets, you can use it anywhere,
just by pushing it around, or spawning it however you want, by
making use of the PushSpecs, DynSpawnSpecs o
StaticSpawnSpecs.
Implementations
Sourceimpl Info
impl Info
Sourcepub fn new(text: Text) -> Self
pub fn new(text: Text) -> Self
Returns a new Info widget
This is the only Widget in duat-base that can be
acquired this way, since it’s supposed to be versatile in
where you position it. Every other widget has to be placed in
specific locations, so they don’t offer a new method, which
could be used in order to place them willy nilly.